@@ -1,5 +1,5 @@
 # SystemC - SystemC Perl Interface
-# $Id: File.pm 15713 2006-03-13 17:42:48Z wsnyder $
+# $Id: File.pm 20433 2006-05-19 13:42:08Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -23,7 +23,7 @@ use SystemC::Template;
 use Verilog::Netlist::Subclass;
 @ISA = qw(SystemC::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '1.260';
+$VERSION = '1.261';
 use strict;
 
 structs('new',
@@ -63,7 +63,7 @@ sub new {
     my %params = (@_);	# filename=>
 
     # A new file; make new information
-    $params{fileref} or die "No fileref parameter?";
+    $params{fileref} or die "%Error: No fileref parameter?";
     $params{netlist} = $params{fileref}->netlist;
     my $parser = $class->SUPER::new (%params,
 				     modref=>undef,	# Module being parsed now
@@ -753,7 +753,7 @@ sub enum_value {
     my $class = $self->{class} || "TOP";
     my $href = $fileref->_enums() || {};
     if (!defined $href->{$class}{$enum}) {
-	$self->{_last_enum_value} = 0;
+	$self->{_last_enum_value} = -1;  # So first enum gets '0'
     }
     # If user didn't specify a value, C++ simply increments from the last value
     if (($value||"") eq "") {
